@@ -4,19 +4,21 @@ import atexit
 import codecs
 import functools
 import gettext
-from http.cookiejar import CookieJar, MozillaCookieJar
+from http.cookiejar import CookieJar
 import itertools
 import logging
 import os.path
 import ssl
 import sys
 import tempfile
+
 import tornado.ioloop
 import tornado.testing
 
 from wpull.converter import BatchDocumentConverter
-from wpull.cookie import CookieLimitsPolicy
+from wpull.cookie import CookieLimitsPolicy, RelaxedMozillaCookieJar
 from wpull.database import URLTable
+from wpull.debug import DebugConsoleHandler
 from wpull.engine import Engine
 from wpull.factory import Factory
 from wpull.hook import HookEnvironment
@@ -129,6 +131,7 @@ class Builder(object):
         self._setup_logging()
         self._setup_console_logger()
         self._setup_file_logger()
+        self._setup_debug_console()
         self._install_script_hooks()
         self._warn_unsafe_options()
         self._warn_silly_options()
@@ -325,6 +328,22 @@ class Builder(object):
             hook_environment.web_processor_factory)
         self._factory.set('Resolver', hook_environment.resolver_factory)
 
+    def _setup_debug_console(self):
+        if not self._args.debug_console_port:
+            return
+
+        _logger.warning(
+            _('Opened a debug console at localhost:{port}.')\
+            .format(port=self._args.debug_console_port)
+        )
+
+        application = tornado.web.Application(
+            [(r'/', DebugConsoleHandler)],
+            builder=self
+        )
+        http_server = tornado.httpserver.HTTPServer(application)
+        http_server.listen(self._args.debug_console_port, address='localhost')
+
     def _build_input_urls(self, default_scheme='http'):
         '''Read the URLs provided by the user.'''
 
@@ -645,7 +664,6 @@ class Builder(object):
             retry_connrefused=args.retry_connrefused,
             retry_dns_error=args.retry_dns_error,
             post_data=post_data,
-            strong_robots=args.strong_robots,
             strong_redirects=args.strong_redirects,
             content_on_error=args.content_on_error,
         )
@@ -852,7 +870,7 @@ class Builder(object):
             return
 
         if self._args.load_cookies or self._args.save_cookies:
-            self._factory.set('CookieJar', MozillaCookieJar)
+            self._factory.set('CookieJar', RelaxedMozillaCookieJar)
 
             cookie_jar = self._factory.new('CookieJar')
 
@@ -940,6 +958,7 @@ class Builder(object):
             num_scrolls=self._args.phantomjs_scroll,
             warc_recorder=self.factory.get('WARCRecorder'),
             smart_scroll=self._args.phantomjs_smart_scroll,
+            snapshot=self._args.phantomjs_snapshot,
         )
 
         return phantomjs_controller
